/**
 * @typedef NextReturnObject An Object with two properties. 
 * @type {object}
 * @property {boolean} done <ul><li>Has the value <code>true</code> if 
 * the iterator is past the end of the iterated sequence. In this 
 * case <code>value</code> optionally specifies the <em>return value</em> 
 * of the iterator.</li>
 * <li>Has the value <code>false</code> if the iterator was able to produce 
 * the next value in the sequence. This is equivalent of not specifying 
 * the <code>done</code> property altogether.</li></ul>
 * @property {object} value any JavaScript value returned by the iterator. 
 * Can be omitted when done is true.
 */

/**
 * The Generator object is returned by a generator function and it conforms 
 * to both the iterable protocol and the iterator protocol.
 */
var Generator = {}

/**
 * The next() method returns an object with two properties done and value. 
 * You can also provide a parameter to the next method to send a value to the generator.
 * @param {object} value
 * @returns {NextReturnObject}  
 */
Generator.prototype.next = function (value){
};

/**
 * The return() method returns the given value and finishes the generator.
 * @param {object} value The value to return.
 * @returns {object} Returns the value that is given as an argument to this function.
 */
Generator.prototype.return = function (value){};

/**
 * The throw() method throws an error to a generator.
 * @param {object} exception The exception to throw. For debugging purposes, it is useful to make it an instanceof Error.
 * @returns {undefined}
 */
Generator.prototype.throw = function (exception){};